$TITLE Core simulation file. Standard CGE modeling system, Version 1.00
$OFFSYMLIST OFFSYMXREF

OPTIONS ITERLIM=10000, LIMROW=0, LIMCOL=0
        SOLPRINT=OFF , MCP=PATH, NLP=MINOS5;
*These options work if the experiments run without solver errors. If there
*are solution problems, for debugging, it is worthwhile to set the options
*to their values in MOD100.GMS.

$ontext
Version 1.00 Release date: May 02, 2001
Last update:


The file contents in outline:
1. SETS FOR SIMULATIONS
2. DEFINING EXPERIMENT PARAMETERS
3. DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS
4. DEFINING CLOSURES FOR FACTOR MARKETS
5. REPORT SETUP
6. LOOP
7. COMPUTING PERCENTAGE CHANGE FOR REPORT PARAMETERS
8. CHECKING FOR GAP ERROR IN REPORT PARAMETERS
9. DISPLAYING REPORTS

The purpose of the simulations that are implemented is to demonstrate
the use of the simulation file.

Note on standard steps when implementing a new simulation:

a. Add element to the set SIM (cf. TARCUT1)
b. If needed, declare new experiment parameter(s) (cf. TMSIM);
c. For the relevant experiment parameters, define default value
   (if new) and value for new simulation (cf. TMSIM).
d. Create report parameters (included in REPLOOP.INC and REPPERC.INC)
   for each new model parameter that is subject to change in new
   experiments.
e. Verify that default macro and factor market closures are OK;
   if not, select different closures for the new simulation
   (see SICLOS, GOVCLOS, ROWCLOS, FACTFE, FMOBFE, FMOBUE)
f. In the beginning of the loop, impose the value of the
   experiment parameter. If the parameter is new, additional code
   is required (cf. tm and TMSIM in LOOP)
g. Include the simulation in SIMCUR.
h. Save and run the simulation file.


$offtext

*1. SETS FOR SIMULATIONS=============================================

SET
 SIM  simulations
 /
 BASE      base simulation
 TARCUT1   50% cut in tariffs + flex gov sav
 TARCUT2   50% cut in tariffs + fixed gov sav
 FSAVINCR  10% increase in foreign savings with default closures
 PWMINCR   10% increase in import prices
 PWEINCR   10% increase in export prices
 DEVAL     10% devaluation
 FISCEXP   10% increase in govt expend on goods & services
 TRANSF    100% increase in existing govt transf to poor (bottom 40%)hh
 WAGINCR   10% econ-wide incr in wage rate of lablo & labmed with unemploym only
 TQEINCR   10 times increase in the sales tax on electricity
 TRCDECR   50% reduction in domestic transaction costs
/

 SIMCUR(SIM)     current simulations
 SIMBASINIT(SIM) simulations with variable initialized at base level
 ;


*By defining SIMCUR, the user selects the experiments that are
*carried out. BASE should always be included in SIMCUR.

 SIMCUR('BASE')     = YES;
 SIMCUR('TARCUT1')  = YES;
 SIMCUR('TARCUT2')  = YES;
 SIMCUR('FSAVINCR') = YES;
 SIMCUR('PWMINCR')  = YES;
 SIMCUR('PWEINCR')  = YES;
 SIMCUR('DEVAL')    = YES;
 SIMCUR('FISCEXP')  = YES;
 SIMCUR('TRANSF')   = YES;
 SIMCUR('WAGINCR')  = YES;
 SIMCUR('TQEINCR')  = YES;
 SIMCUR('TRCDECR')  = YES;

*Variable initializations at base level may provide a better starting
*point for selected simulations (depending on the content of the
*preceding simulation).

 SIMBASINIT(SIM)   = NO;
 SIMBASINIT(SIM)   = YES;

DISPLAY SIM, SIMCUR, SIMBASINIT;


*END: SETS FOR SIMULATIONS===========================================
*2. DEFINING EXPERIMENT PARAMETERS===================================

PARAMETERS
 TMSIM(C,SIM)         tariff rate for com c by sim

*Closure variables that may be changed exogenously in simulations
*The values defined for these parameters matter only if the related
*variable is fixed
 FSAVSIM(SIM)         foreign savings by sim (in for curr units i.e. FCU)
 IADJSIM(SIM)         investment adjustment factor by sim
 EXRSIM(SIM)          exchange rate by sim
 GSAVSIM(SIM)         government savings by sim
 PWMSIM(C,SIM)        price for imports of c in FCU
 PWESIM(C,SIM)        price for exports of c in FCU
 GADJSIM(SIM)         government adjustment factor by sim
 TRNSFSIM(INS,AC,SIM) transfer adjustment factor by sim
 WAGSIM(F,SIM)        econ-wide incr in wage rate of lablo & labmed with unemploym only
 TQESIM(C,SIM)        increase in the sales tax of electricity
 TRCSIM(C,C,SIM)      reduction in domestic transaction costs
 ;

*Unless specified otherwise below, base values are used
 TMSIM(C,SIM)        = tm(C);
 FSAVSIM(SIM)        = FSAV0;
 IADJSIM(SIM)        = IADJ0;
 EXRSIM(SIM)         = EXR0;
 GSAVSIM(SIM)        = GSAV0;
 PWMSIM(C,SIM)       = pwm0(C);
 PWESIM(C,SIM)       = pwe0(C);
 GADJSIM(SIM)        = GADJ0;
 TRNSFSIM(INS,AC,SIM)= trnsfr(INS,AC);
 WAGSIM(F,SIM)       = WF0(F);
 TQESIM(C,SIM)       = tq0(C);
 TRCSIM(CT,C,SIM)    = icd(CT,C);


*Specifying non-base values for experiment parameters

*TARCUT1   50% cut in tariffs + flex gov sav + mobile factors
 TMSIM(C,'TARCUT1')             = 0.5*TM0(C);
*TARCUT2   50% cut in tariffs + fixed gov sav + mobile factors
 TMSIM(C,'TARCUT2')             = 0.5*TM0(C);
*FSAVINCR  10% increase in foreign savings with default closures
 FSAVSIM('FSAVINCR')            = 1.1*FSAV0;
*PWMINCR   10% increase in import prices
 PWMSIM(C,'PWMINCR')            = 1.1*pwm0(C);
*PWEINCR   10% increase in export prices
 PWESIM(C,'PWEINCR')            = 1.1*pwe0(C);
*DEVAL     10% devaluation + act specific capital
 EXRSIM('DEVAL')                = 1.1*EXR0;
*FISCEXP   10% increase in govt expend on goods & services
 GADJSIM('FISCEXP')             = 1.1*GADJ0;
*TRANSF    100% increase in existing govt transf to poor households
 TRNSFSIM('HHD0','GOV','TRANSF')= 2*trnsfr('HHd0','GOV');
 TRNSFSIM('HHD1','GOV','TRANSF')= 2*trnsfr('HHd1','GOV');
 TRNSFSIM('HHD2','GOV','TRANSF')= 2*trnsfr('HHd2','GOV');
 TRNSFSIM('HHD3','GOV','TRANSF')= 2*trnsfr('HHd3','GOV');
*WAGINCR   10% econ-wide incr in wage rate of lablo & labmed with unemploym only
 WAGSIM('LABLO','WAGINCR')      = 1.1*WF0('LABLO');
 WAGSIM('LABMED','WAGINCR')     = 1.1*WF0('LABMED');
*TQEINCR    100% increase in the sales tax on electricity
 TQESIM('c_elegs','TQEINCR')     = 10* tq('c_elegs');
*TRCDECR   50% reduction in domestic transaction costs
 TRCSIM(CT,C,'TRCDECR')         = 0.5*icd(CT,C);

DISPLAY
 TMSIM, FSAVSIM, PWMSIM, PWESIM, IADJSIM,EXRSIM, GSAVSIM, GADJSIM, TRNSFSIM
 WF0, WAGSIM, TQESIM, TRCSIM;


*END: DEFINING EXPERIMENT PARAMETERS=================================
*3. DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS===================

*Inside the solution loop, the selection of values for SICLOS, ROWCLOS,
*and GOVCLOS determine the selection of variables that are fixed
*and flexible.

PARAMETERS

 SICLOS(SIM) value for savings-investment closure
*SICLOS = 1 ---> inv-driven sav -- uniform mps rate point change for
*                selected ins
*SICLOS = 2 ---> inv-driven sav -- scaled mps for for selected ins
*SICLOS = 3 ---> inv is sav-driven
*SICLOS = 4 ---> inv and gov are fixed abs share
*                - uniform mps rate point change (cf. 1)
*SICLOS = 5 ---> inv is fixed abs share - scaled mps (cf. 2)
*Note: SICLOS 4 and 5 are examples of balanced closures.

 ROWCLOS(SIM) value for rest-of-world closure
*ROWCLOS = 1 ---> exch rate is flexible, for savings are fixed
*ROWCLOS = 2 ---> exch rate is fixed   , for savings are flexible

 GOVCLOS(SIM) value for government closure
*GOVCLOS = 1 ---> gov savings are flexible, dir tax rate is fixed
*GOVCLOS = 2 ---> gov savings are fixed   ,
*                 uniform dir tax rate point change for selected ins
*GOVCLOS = 3 ---> gov savings are fixed   ,
*                 scaled dir tax rate for selected institutions


 MPS01SIM(INS,SIM)   0-1 par for potential flexing of savings rates
 TINS01SIM(INS,SIM)  0-1 par for potential flexing of dir tax rates
 ;


*SICLOS, ROWCLOS, and GOVCLOS are set at default values
 SICLOS(SIM)     = 2;
 ROWCLOS(SIM)    = 1;
 GOVCLOS(SIM)    = 1;

*For closures with flexible savings or direct tax rates, the default
*is that the rates of all domestic non-government institutions adjust
*Alternatively it is possible to identify certain domestic non government
*institutions (poor households, or firms) that are exluded from the
*savings and tax rate adjustment for certain simulations by assigning
* them with a zero below the following statment:
 MPS01SIM(INSDNG,SIM)   = 1;
 TINS01SIM(INSDNG,SIM)  = 1;

*Here: overwrite values for SICLOS, ROWCLOS, and GOVCLOS for selected
*simulations
 GOVCLOS('TARCUT1')   = 1;
 GOVCLOS('TARCUT2')   = 2;
 ROWCLOS('DEVAL')     = 2;
 GOVCLOS('FISCEXP')   = 1;
 GOVCLOS('TRANSF')    = 1;

DISPLAY SICLOS, GOVCLOS, ROWCLOS, MPS01SIM, TINS01SIM;

*END: DEFINING CLOSURES FOR MACRO SYSTEM CONSTRAINTS=================
*4. DEFINING CLOSURES FOR FACTOR MARKETS=============================

*Inside the solution loop, the selection of values for FMOBFE, FACTFE,
*and FMOBUE determine the selection of variables that are fixed
*and flexible.


PARAMETERS
 FMOBFE(F,SIM)  factor f is fully employed & mobile in sim
 FACTFE(F,SIM)  factor f is fully employed & activity-specific in sim
 FMOBUE(F,SIM)  factor f is unemployed & mobile in sim

;
*Default specification of factor market closures
*Note that, for every simulation, every factor should have a non-zero
*value for exactly one of the three parameters.

*Capital is assumed to be fully employed and activity-specific in all sims
 FMOBFE("CAP",SIM) = 0;
 FACTFE("CAP",SIM) = 1;
 FMOBUE("CAP",SIM) = 0;

*Higly skilled labour  is assumed to be fully employed and act-spec in all sims
 FMOBFE("LABHI",SIM) = 0;
 FACTFE("LABHI",SIM) = 1;
 FMOBUE("LABHI",SIM) = 0;

*Medium skilled labour is assumed to be mobile but unemployed
 FMOBFE("LABMED",SIM) = 0;
 FACTFE("LABMED",SIM) = 0;
 FMOBUE("LABMED",SIM) = 1;

*Low skilled labour is assumed to be mobile but unemployed
 FMOBFE("LABLO",SIM) = 0;
 FACTFE("LABLO",SIM) = 0;
 FMOBUE("LABLO",SIM) = 1;
*Here: overwrite values for FMOBFE, FACTFE, and FMOBUE for selected
*simulations:

$ONTEXT
 FMOBFE(FLAB,'DEVAL') = 1;
 FMOBFE(FCAP,'DEVAL') = 0;

 FACTFE(FLAB,'DEVAL') = 0;
 FACTFE(FCAP,'DEVAL') = 1;

 FMOBUE(F,'DEVAL')    = 0;
$OFFTEXT


*Checking for errors in factor market closures

PARAMETER
 ERRFCLOS(F,SIM) UNDF error if not exactly one closure by f and sim
*Error if any factor f, in each simulation, does not have a non-zero
*value for exactly one of the three parameters FMOBFE, FACTFE, FMOBUE.
 ;
 ERRFCLOS(F,SIM)$(FMOBFE(F,SIM)+ FACTFE(F,SIM)+ FMOBUE(F,SIM) NE 1) = 1/0;

DISPLAY ERRFCLOS, FMOBFE, FACTFE, FMOBUE;


*5. REPORT SETUP=================================================

*SET AND PARAMETERS FOR REPORTS++++++++


SET

 SAC  SAM account categories
 /
 ACT     activities
 COM     commodities
 FAC     factors
 INSDNG  domestic non-government institutions
 GOV     government
 SAVINV  savings-investments
 INSTAX  direct taxes on institutions
 FACTAX  direct taxes on factors
 VATAX   value added tax
 ACTTAX  tax on activity gross revenue
 COMTAX  tax on commodity sales in the domestic market
 IMPTAX  import tariff
 EXPTAX  export tax
 ROW     rest of world (FCU)
 /

 IND3  third index for SAM budgets
 /
 INC
 SPND
 GAP
 /

 KGDP  first index in GDP tables
 /
 NOMINAL, REAL, NOMSHARE, REALSHARE, DEFLATOR
 /

 IGDP  Items for GDP and national accounts
  /
  ABSORP   absorption
  PRVCON   private consumption
  FIXINV   fixed investment
  DSTOCK   stock change
  GOVCON   government consumption
  EXPORTS  exports
  IMPORTS  imports
  GDPMP    GDP at market prices (alt. 1: spending)
  GDPMP2   GDP at market prices (alt. 2: value-added)
  NETITAX  net indirect taxes
  GDPFC2   GDP at factor cost
  /

 IGDP2(IGDP)  Items for GDPMP summation
  /
  PRVCON   private consumption
  FIXINV   fixed investment
  DSTOCK   stock change
  GOVCON   government consumption
  EXPORTS  exports
  IMPORTS  imports
  /
 ;


*==========================================================
*Report parameters in LOOP=================================
*==========================================================
PARAMETERS
*Values for all model variables============================
*Values for all model variables (variable name + X)========
 CPIX(SIM)        consumer price index (PQ-based)
 DPIX(SIM)        index for domestic producer prices (PDS-based)
 DMPSX(SIM)       change in marginal propensity to save for selected inst
 DTINSX(SIM)      change in domestic institution tax share
 EGX(SIM)         total current government expenditure
 EHX(H,SIM)       household consumption expenditure
 EXRX(SIM)        exchange rate
 FSAVX(SIM)       foreign savings
 GADJX(SIM)       government demand scaling factor
 GOVSHRX(SIM)     govt consumption share of absorption
 GSAVX(SIM)       government savings
 IADJX(SIM)       investment scaling factor (for fixed capital formation)
 INVSHRX(SIM)     investment share of absorption
 MPSX(INS,SIM)    marginal propensity to save for dom non-gov inst ins
 MPSADJX(SIM)     savings rate scaling factor
 PAX(A,SIM)       output price of activity a
 PDDX(C,SIM)      demand price for com'y c produced & sold domestically
 PDSX(C,SIM)      supply price for com'y c produced & sold domestically
 PEX(C,SIM)       price of exports
 PINTAX(A,SIM)    price of intermediate aggregate
 PMX(C,SIM)       price of imports
 PQX(C,SIM)       price of composite good c
 PVAX(A,SIM)      value added price
 PWEX(C,SIM)      world price of exports
 PWMX(C,SIM)      world price of imports
 PXX(C,SIM)       average output price
 PXACX(A,C,SIM)   price of commodity c from activity a
 QAX(A,SIM)       level of domestic activity
 QDX(C,SIM)       qnty of domestic sales
 QEX(C,SIM)       qnty of exports
 QFX(F,A,SIM)     qnty demanded of factor f from activity a
 QFSX(F,SIM)      qnty of factor supply
 QGX(C,SIM)       qnty of government consumption
 QHX(C,H,SIM)     qnty consumed of market commodity c by household h
 QHAX(A,C,H,SIM)  qnty consumed of home commodity c fr act a by hhd h
 QINTX(C,A,SIM)   qnty of intermediate demand for c from activity a
 QINTAX(A,SIM)    qnty of aggregate intermediate input
 QINVX(C,SIM)     qnty of fixed investment demand
 QMX(C,SIM)       qnty of imports
 QQX(C,SIM)       qnty of composite goods supply
 QTX(C,SIM)       qnty of trade and transport demand for commodity c
 QVAX(A,SIM)      qnty of aggregate value added
 QXX(C,SIM)       qnty of aggregate marketed commodity output
 QXACX(A,C,SIM)   qnty of ouput of commodity c from activity a
 TABSX(SIM)       total absorption
 TINSX(INS,SIM)   rate of direct tax on domestic institutions ins
 TINSADJX(SIM)    direct tax scaling factor
 TRIIX(INS,INSP,SIM) transfers to dom. inst. insdng from insdngp
 WALRASX(SIM)     savings-investment imbalance (should be zero)
 WFX(F,SIM)       economy-wide wage (rent) for factor f
 WFDISTX(F,A,SIM) factor wage distortion variable
 YFX(F,SIM)       factor income
 YGX(SIM)         total current government income
 YIFX(INS,F,SIM)  income of institution ins from factor f
 YIX(INS,SIM)     income of (domestic non-governmental) institution ins
 WFAX(F,A,SIM)    price of factor f for activity a

*Budgets for SAM accounts==================================
 SAMBUD(SAC,AC,IND3,AC,SIM)  budgets for SAM accounts
*Note: For RoW, for exch earnings of model country defined as income;
*for exch spending of model country defined as spending

*National accounts data=====================================
 GDPTAB1(KGDP,IGDP,SIM) GDP and national accounts
 GDPTAB2(KGDP,AC,SIM)   GDP at factor cost by activity

*Macro and factor closures=================================
 MACCLOS(*,SIM)      Macro closures actually used (by sim)
 FACCLOS(F,*,SIM)    Factor closures actually used (by sim and f)

*==========================================================
*Post-calculated report parameters=========================
*==========================================================
*% change in LOOP parameters: above parameter name + P
*For base, these parameters show the base value.(%ch)
 CPIXP(SIM)        consumer price index (PQ-based) (%ch)
 DPIXP(SIM)        index for dom producer prices (PDS-based) (%ch)
*DMPSXP(SIM)       zero for base
*DTINSXP(SIM)      zero for base
 EGXP(SIM)         total current gov expenditure (%ch)
 EHXP(H,SIM)       hhd consumption expenditure (%ch)
 EXRXP(SIM)        exchange rate (%ch)
 FSAVXP(SIM)       foreign savings (%ch)
 GADJXP(SIM)       gov demand scaling factor (%ch)
 GOVSHRXP(SIM)     govt consumption share of absorption (%ch)
 GSAVXP(SIM)       gov savings (%ch)
 IADJXP(SIM)       fixed investment scaling factor (%ch)
 INVSHRXP(SIM)     investment share of absorption (%ch)
 MPSXP(INS,SIM)    marg prop to save for dom non-gov inst ins (%ch)
*MPSADJXP(SIM)     zero for base
 PAXP(A,SIM)       output price of activity a (%ch)
 PDDXP(C,SIM)      demand price for com'y c produced & sold dom'ly (%ch)
 PDSXP(C,SIM)      supply price for com'y c produced & sold dom'ly (%ch)
 PEXP(C,SIM)       price of exports (%ch)
 PINTAXP(A,SIM)    price of intermediate aggregate (%ch)
 PMXP(C,SIM)       price of imports (%ch)
 PQXP(C,SIM)       price of composite good c (%ch)
 PVAXP(A,SIM)      value added price (%ch)
 PWEXP(C,SIM)      world price of exports (%ch)
 PWMXP(C,SIM)      world price of imports (%ch)
 PXXP(C,SIM)       average output price (%ch)
 PXACXP(A,C,SIM)   price of comm c from activity a (%ch)
 QAXP(A,SIM)       level of dom activity (%ch)
 QDXP(C,SIM)       qnty of dom sales (%ch)
 QEXP(C,SIM)       qnty of exports (%ch)
 QFXP(F,A,SIM)     qnty demanded of factor f from activity a (%ch)
 QFSXP(F,SIM)      qnty of factor supply (%ch)
 QGXP(C,SIM)       qnty of gov consumption (%ch)
 QHXP(C,H,SIM)     qnty consumed of market comm c by hhd h (%ch)
 QHAXP(A,C,H,SIM)  qnty consumed of home comm c fr act a by hhd h (%ch)
 QINTXP(C,A,SIM)   qnty of intermediate demand for c from act'y a (%ch)
 QINTAXP(A,SIM)    qnty of aggregate intermediate input (%ch)
 QINVXP(C,SIM)     qnty of fixed investment demand (%ch)
 QMXP(C,SIM)       qnty of imports (%ch)
 QQXP(C,SIM)       qnty of composite goods supply (%ch)
 QTXP(C,SIM)       qnty of trade and transport demand for comm c (%ch)
 QVAXP(A,SIM)      qnty of aggregate value added (%ch)
 QXXP(C,SIM)       qnty of aggregate marketed comm output (%ch)
 QXACXP(A,C,SIM)   qnty of ouput of comm c from activity a (%ch)
 TABSXP(SIM)       total absorption (%ch)
 TINSXP(INS,SIM)   rate of direct tax on dom institutions ins (%ch)
*TINSADJXP(SIM)    zero for base
 TRIIXP(INS,INSP,SIM) transfers to dom. inst. insdng from insdngp (%ch)
*WALRASXP(SIM)     zero for base
 WFXP(F,SIM)       economy-wide wage (rent) for factor f (%ch)
 WFDISTXP(F,A,SIM) factor wage distortion variable (%ch)
 YFXP(F,SIM)       factor income (%ch)
 YGXP(SIM)         total current gov income (%ch)
 YIFXP(INS,F,SIM)  income of institution ins from factor f (%ch)
 YIXP(INS,SIM)     income of (dom non-gov) institution ins (%ch)

 WFAXP(F,A,SIM)  price of factor f for activity a (%ch)

*Other %-age change reports
 SAMBUDP(SAC,AC,IND3,AC,SIM) budgets for SAM accounts (%ch for non-base)
 GDPTAB1P(KGDP,IGDP,SIM) GDP and national accounts (%ch for non-base)
 GDPTAB2P(KGDP,AC,SIM)   GDP at f.c. by activity (%ch for non-base)

*Consistency checks==================================================
 SAMBUDGAP(SAC,AC,SIM)   abs value of inc-spnd gaps for SAM account budgets
 GDPGAP(SIM)             gaps in GDP reports
 GAPWARNING(SIM)         error message if abs gap above limit
 ;


*====================================================================
*6. L O O P==========================================================
*====================================================================
LOOP(SIMCUR,

*This include statement is optional. It may facilitate solver
*performance by providing better starting point.
*IF(SIMBASINIT(SIMCUR),
*$INCLUDE VARINIT.INC
*);

*IMPOSING PARAMETER  & FIXED VARIABLE VALUES FOR EXPERIMENTS=========
*In this section, changes in experiment parameters and fixed
*variables are imposed, except for changes in fixed variables related to
*closures, which are handled in the next section.

 tm(C)          = TMSIM(C,SIMCUR);
 PWM.FX(C)      = PWMSIM(C,SIMCUR);
 PWE.fx(C)      = PWESIM(C,SIMCUR);
 trnsfr(INS,AC) = TRNSFSIM(INS,AC,SIMCUR);
 tq('c_elegs')   = TQESIM('c_elegs',SIMCUR);
 icd(CT,C)      = TRCSIM(CT,C,SIMCUR);


DISPLAY tm, PWM0, PWM.l, PWE0, PWE.l, trnsfr, WF0, WF.L;

*IMPOSING CLOSURES FOR SYSTEM CONSTRAINTS============================

*Selecting institutions with potentially flexible savings and direct
*tax rates. This setting only matters for some of the alternative
*savings-investment and government closures.
 mps01(INSDNG)  = MPS01SIM(INSDNG,SIMCUR);
 tins01(INSDNG) = TINS01SIM(INSDNG,SIMCUR);

*-------------------------Closures on Government Finance------------------------

IF(GOVCLOS(SIMCUR) EQ 1,
*Fixed direct tax rates
*Flexible government savings
 TINSADJ.FX = TINSADJ0;
 DTINS.FX   = DTINS0  ;
 GSAV.LO    = -INF    ; GSAV.UP   = +INF; GSAV.L   = GSAV0;
 );

IF(GOVCLOS(SIMCUR) EQ 2,
*Uniform direct tax rate point change for selected institutions, i.e., we're
*adding the same percentage change (for which we solve: DTINS) to the
*initial tax rate. This may seem harsh on the poor as their tax rate
*will now increase say from 1% to 3%, if DTINS is 2%, while the rate
*for the rich will increase from 20% to 22%.
*Fixed government savings
 TINSADJ.FX = TINSADJ0;
 DTINS.LO   = -INF    ; DTINS.UP  = +INF; DTINS.L  = DTINS0;
 GSAV.FX    = GSAVSIM(SIMCUR);
 );

IF(GOVCLOS(SIMCUR) EQ 3,
*Scaled or proportionally channged direct tax rates for selected institutions
*which seems more fair if the TINSADJ is solved for and appears to be 25%,
*the initial tax rate of a poor household will increase from 1% to 1.25%,
*while the tax rate of a rich household will increase from 20% to 24%
*Fixed government savings
 TINSADJ.LO = -INF   ; TINSADJ.UP = +INF   ; TINSADJ.L = TINSADJ0;
 DTINS.FX   = DTINS0 ; DTINS.L    = DTINS0 ;
 GSAV.FX    = GSAVSIM(SIMCUR);
 );

*-------------------------Closures on the Foreign Sector------------------------

IF(ROWCLOS(SIMCUR) EQ 1,
*Fixed foreign savings -- flexible exchange rate
 FSAV.FX = FSAVSIM(SIMCUR);
 EXR.LO  = -INF; EXR.UP  = +INF; EXR.L   = EXR0;                                                          );

IF(ROWCLOS(SIMCUR) EQ 2,
*Fixed exchange rate -- flexible foreign savings
 EXR.FX = EXRSIM(SIMCUR);
 FSAV.LO = -INF; FSAV.UP = +INF; FSAV.L = FSAV0;
                                                          );
*--------------------------Closures on Savings & Investment---------------------

IF(SICLOS(SIMCUR) EQ 1,
*Investment-driven savings
*Uniform MPS rate point change for selected ins, i.e. we're adding the same
*percentage (for which we solve) to the MPS of all households. This may seem
*far fetched
 MPSADJ.FX = MPSADJ0;
 DMPS.LO = -INF; DMPS.UP = +INF; DMPS.L = DMPS0;
*Fixed investment demand quantity adjustment factors
*Flexible absorption shares for investment demand. This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*IADJ and the denominator is flexible because GDP moves around, the ratio
*INVSHR needs to be able to move around
 IADJ.FX       = IADJSIM(SIMCUR);
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand.  This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*GADJ and the denominator is flexible because GDP moves around, the ratio
*GOVSHR needs to be able to move around
 GADJ.FX   = GADJSIM(SIMCUR);
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 2,
*Investment-driven savings
*Scaled MPS for selected institutions, i.e., were multiplying the MPS with
*the same factor (for which we solve, MPSADJ), i.e. if the savings is
*initially low for poor households it will remain low for the simulation,
*while rich households will see their savings rate increase substantially
 MPSADJ.LO = -INF; MPSADJ.UP = +INF; MPSADJ.L = MPSADJ0;
 DMPS.FX = DMPS0;
*Fixed investment demand quantity adjustment factors
*Flexible absorption shares for investment demand. This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*IADJ and the denominator is flexible because GDP moves around, the ratio
*INVSHR needs to be able to move around
 IADJ.FX = IADJSIM(SIMCUR);
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand.  This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*GADJ and the denominator is flexible because GDP moves around, the ratio
*GOVSHR needs to be able to move around
 GADJ.FX   = GADJSIM(SIMCUR);
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 3,
*Savings-driven investment
*Fixed marginal savings propensities
 MPSADJ.FX = MPSADJ0;
 DMPS.FX = DMPS0;
*Flexible investment demand quantity adjustment factors
*Flexible absorption shares for investment demand. This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*IADJ and the denominator is flexible because GDP moves around, the ratio
*INVSHR needs to be able to move around
 IADJ.LO = -INF; IADJ.UP = +INF;  IADJ.L = IADJ0;
 INVSHR.LO = -INF; INVSHR.UP = +INF; INVSHR.L = INVSHR0;
*Fixed government demand quantity adjustment factors
*Flexible absorption share for government demand.This is necessary because
*GDP or rather absorption is moving around due to the flexible supply of
*unskilled labour (see below), so if the numerator is fixed because of fixed
*GADJ and the denominator is flexible because GDP moves around, the ratio
*GOVSHR needs to be able to move around
 GADJ.FX   = GADJSIM(SIMCUR);
 GOVSHR.LO = -INF; GOVSHR.UP = +INF; GOVSHR.L = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 4,
*Balanced closure.
*Uniform MPS rate point change for selected ins
 MPSADJ.FX = MPSADJ0;
 DMPS.LO = -INF; DMPS.UP = +INF; DMPS.L = DMPS0;
*Flexible investment demand quantity adjustment factors
*Fixed absorption shares for investment demand. This
*is necessary because GDP or rather absorption moves around due to the
*flexible supply of low skilled labour and if the numerator (IADJ) is
*flexible and the denominator (GDP or absorption) is also moving around,
*we have to fix the ratio (INVSHR)
 IADJ.LO = -INF; IADJ.UP = +INF;  IADJ.L = IADJ0;
 INVSHR.FX = INVSHR0;
*Flexible government demand quantity adjustment factors
*Fixed absorption share for government demand. This
*is necessary because GDP or rather absorption moves around due to the
*flexible supply of low skilled labour and if the numerator (GADJ) is
*flexible  and the denominator is moving around, we have to fix the ratio
 GADJ.LO = -INF; GADJ.UP = +INF;  GADJ.L = GADJ0;
 GOVSHR.FX = GOVSHR0;
 );

IF(SICLOS(SIMCUR) EQ 5,
*Balanced closure.
*Scaled MPS for selected institutions
 MPSADJ.LO = -INF; MPSADJ.UP = +INF; MPSADJ.L = MPSADJ0;
 DMPS.FX = DMPS0;
*Flexible investment demand quantity adjustment factors
*Fixed absorption shares for investment demand. This
*is necessary because GDP or rather absorption moves around due to the
*flexible supply of low skilled labour and if the numerator (IADJ) is
*flexible and the denominator (GDP or absorption) is also moving around,
*we have to fix the ratio (INVSHR)
 IADJ.LO = -INF; IADJ.UP = +INF;  IADJ.L = IADJ0;
 INVSHR.FX = INVSHR0;
*Flexible government demand quantity adjustment factors
*Fixed absorption share for government demand. This
*is necessary because GDP or rather absorption moves around due to the
*flexible supply of low skilled labour and if the numerator (GADJ) is
*flexible  and the denominator is moving around, we have to fix the ratio
 GADJ.LO = -INF; GADJ.UP = +INF;  GADJ.L = GADJ0;
 GOVSHR.FX = GOVSHR0;
 );

*---------------------
*For factors with FMOBFE(F,SIMCUR) > 0
*Factors in FMOBFE are fully employed and mobile between activities.
*WF(F) is the market-clearing variable each factor market (as
*specified above).

 WFDIST.FX(F,A)$FMOBFE(F,SIMCUR) = WFDIST0(F,A);
 QFS.FX(F)$FMOBFE(F,SIMCUR)      = QFS0(F);

 WF.LO(F)$FMOBFE(F,SIMCUR)       = -INF;
 WF.UP(F)$FMOBFE(F,SIMCUR)       = +INF;
 WF.L(F)$FMOBFE(F,SIMCUR)        = WF0(F);

 QF.LO(F,A)$(FMOBFE(F,SIMCUR)$(QF0(F,A))) = -INF;
 QF.UP(F,A)$(FMOBFE(F,SIMCUR)$(QF0(F,A))) = +INF;
 QF.L(F,A)$(FMOBFE(F,SIMCUR)$(QF0(F,A)))  = QF0(F,A);

*---------------------
*For factors with FACTFE(F,SIMCUR) > 0
*Factors in FACTFE are fully employed and activity-specific.
*WFDIST(F,A) is the clearing variable, one for each segment of the
*factor market (as specified above).

 WF.FX(F)$FACTFE(F,SIMCUR)   = WF0(F);
 QF.FX(F,A)$FACTFE(F,SIMCUR) = QF0(F,A);

 WFDIST.LO(F,A)$(FACTFE(F,SIMCUR)$(QF0(F,A))) = -INF;
 WFDIST.UP(F,A)$(FACTFE(F,SIMCUR)$(QF0(F,A))) = +INF;
 WFDIST.L(F,A)$(FACTFE(F,SIMCUR)$(QF0(F,A)))  = WFDIST0(F,A);

 QFS.LO(F)$FACTFE(F,SIMCUR) = -INF;
 QFS.UP(F)$FACTFE(F,SIMCUR) = +INF;
 QFS.L(F)$FACTFE(F,SIMCUR) = QFS0(F);

*---------------------
*For factors with FMOBUE(F,SIMCUR) > 0
*Factors in FMOBUE are unemployed and mobile. For each activity, the
*wage, WFDIST(F,A)*WF(F), is fixed. QFS(F) is the market-clearing
*variable for the unified facto market (as specified above).
*note that WAGSIM assumes the value WF0 for all but the WAGINCR
*simulations. The latter only runs over LABLO and LABMED

 WFDIST.FX(F,A)$FMOBUE(F,SIMCUR)            = WFDIST0(F,A);
 WF.FX(F)$FMOBUE(F,SIMCUR)                  = WAGSIM(F,SIMCUR);

 QF.LO(F,A)$(FMOBUE(F,SIMCUR)$(QF0(F,A))) = -INF;
 QF.UP(F,A)$(FMOBUE(F,SIMCUR)$(QF0(F,A))) = +INF;
 QF.L(F,A)$(FMOBUE(F,SIMCUR)$(QF0(F,A)))  = QF0(F,A);

 QFS.LO(F)$FMOBUE(F,SIMCUR)      = -INF;
 QFS.UP(F)$FMOBUE(F,SIMCUR)      = +INF;
 QFS.L(F)$FMOBUE(F,SIMCUR)       = QFS0(F);


*SOLVING=============================================================

 SOLVE STANDCGE USING MCP;
*SOLVE NLPCGE MINIMIZING WALRASSQR USING NLP;

*DEFINING REPORT VALUES FOR SIMCUR===================================

$BATINCLUDE REPLOOP.INC SIMCUR

 );
*====================================================================
*END: L O O P========================================================
*====================================================================

*7. COMPUTING PERCENTAGE CHANGE FOR REPORT PARAMETERS================

$INCLUDE REPPERC.INC


*8. CHECKING FOR GAP ERROR IN REPORT PARAMETERS======================
*If error here, check displays of SAMBUDGAP and GDPGAP to find it and
*fix it.
 GAPWARNING(SIM)
   $(SUM(SAC, SAMBUDGAP(SAC,'TOTAL',SIM))+ GDPGAP(SIM) GT 0.00001) = 1/0;

*9. DISPLAYING REPORTS===============================================

OPTION
 QFX:3:1:1    , QHX:3:1:1      , QHAX:3:2:1, QINTX:3:1:1  , WFAX:3:1:1
 WFAX:3:1:1   , WFDISTX:3:1:1  , YFX:3:1:1

 QFXP:3:1:1   , QHXP:3:1:1     , QHAXP:3:2:1, QINTXP:3:1:1, WFAXP:3:1:1
 WFAXP:3:1:1  , WFDISTXP:3:1:1 , YFXP:3:1:1

 SAMBUD:3:1:1 , SAMBUDP:3:1:1
 GDPTAB1:3:1:1, GDPTAB1P:3:1:1
 GDPTAB2:3:1:1, GDPTAB2P:3:1:1
 MACCLOS:0,     FACCLOS:0:1:1
 ;


DISPLAY
*Values for all model variables
CPIX    , DPIX     , DMPSX    , DTINSX   , EGX      , EHX      , EXRX
FSAVX   , GADJX    , GOVSHRX  , GSAVX    , IADJX    , INVSHRX  , MPSX
MPSADJX , PAX      , PDDX     , PDSX     , PEX      , PINTAX   , PMX
PQX     , PVAX     , PWEX     , PWMX     , PXX      , PXACX    , QAX
QDX     , QEX      , QFX      , QFSX     , QGX      , QHX      , QHAX
QINTX   , QINTAX   , QINVX    , QMX      , QQX      , QTX      , QVAX
QXX     , QXACX    , TABSX    , TINSX    , TINSADJX , TRIIX    , WALRASX
WFX     , WFDISTX  , YFX      , YGX      , YIFX     , YIX

*% change for all model variables
CPIXP   , DPIXP    , EGXP     , EHXP     , EXRXP    , FSAVXP   , GADJXP
GOVSHRXP, GSAVXP   , IADJXP   , INVSHRXP , MPSXP    , PAXP     , PDDXP
PDSXP   , PEXP     , PINTAXP  , PMXP     , PQXP     , PVAXP    , PWEXP
PWMXP   , PXXP     , PXACXP   , QAXP     , QDXP     , QEXP     , QFXP
QFSXP   , QGXP     , QHXP     , QHAXP    , QINTXP   , QINTAXP  , QINVXP
QMXP    , QQXP     , QTXP     , QVAXP    , QXXP     , QXACXP   , TABSXP
TINSXP  , TRIIXP   , WFAXP    , WFXP     , WFDISTXP , YFXP     , YGXP
YIFXP   , YIXP

*Other displays
SAMBUD  ,  SAMBUDP , GDPTAB1  , GDPTAB1P , GDPTAB2  , GDPTAB2P

"The parameters MACCLOS and FACCLOS, and the sets ACES and ALEO"
"indicate the values for model features with user choice."

 MACCLOS
 "For GOV"
 "  1 -> gov savings are flexible, dir tax rate is fixed"
 "  2 -> gov savings are fixed"
 "       uniform dir tax rate point chng for selected ins"
 "  3 -> gov savings are fixed"
 "       scaled dir tax rate for selected institutions"
 ""
 "For ROW"
 "  1 -> exch rate is flexible, for savings are fixed"
 "  2 -> exch rate is fixed   , for savings are flexible"
 ""
 "For SAVINV"
  "1 -> inv-driven sav -- uniform mps rate point chng for selected ins"
  "2 -> inv-driven sav -- scaled mps for selected ins"
  "3 -> inv is sav-driven"
  "4 -> inv and gov are fixed abs share - uniform mps rate chng (cf. 1)"
  "5 -> inv and gov are fixed abs share - scaled mps (cf. 2)"
 ""
 FACCLOS
 "FMOBFE = 1 -> mobile and fully employed"
 "FACTFE = 1 -> activity-specific and fully employed"
 "FMOBUE = 1 -> mobile and unemployed"

 ACES
 "Activities in ACES have a CES aggregation function at the top of"
 "the technology nest."

 ALEO
 "Activities in ALEO have a Leontief aggregation function at the top of"
 "the technology nest."

 SIMBASINIT
 "For simulations in SIMBASINIT, the variables are initialized at"
 "base levels."

SAMBUDGAP , GDPGAP  , WALRASX  , GAPWARNING
 ;

$INCLUDE REPSUM.INC


*EOF: END OF FILE================================================